============
Installation
============

At the moment this package uses a fork of yowsup2. While the PR is not merged it is necesary:

At the command line::

	$ pip install -e git+https://github.com/jlmadurga/yowsup.git@issue_1181#egg=yowsup
	$ pip install yowsup-gateway

Cloning from github::

	$ pip install -e git+https://github.com/jlmadurga/yowsup.git@issue_1181#egg=yowsup
    $ git clone https://github.com/jlmadurga/yowsup-gateway.git
	$ cd yowsup-gateway
	$ make install 
